import * as framework from '@powersync/lib-services-framework';
import { GetIntanceOptions, storage, SyncRulesBucketStorage, UpdateSyncRulesOptions } from '@powersync/service-core';
import * as pg_wire from '@powersync/service-jpgwire';
import * as lib_postgres from '@powersync/lib-service-postgres';
import { NormalizedPostgresStorageConfig } from '../types/types.js';
import { PostgresPersistedSyncRulesContent } from './sync-rules/PostgresPersistedSyncRulesContent.js';
export type PostgresBucketStorageOptions = {
    config: NormalizedPostgresStorageConfig;
    slot_name_prefix: string;
};
export declare class PostgresBucketStorageFactory extends framework.BaseObserver<storage.BucketStorageFactoryListener> implements storage.BucketStorageFactory {
    protected options: PostgresBucketStorageOptions;
    readonly db: lib_postgres.DatabaseClient;
    readonly slot_name_prefix: string;
    private activeStorageCache;
    constructor(options: PostgresBucketStorageOptions);
    [Symbol.asyncDispose](): Promise<void>;
    prepareStatements(connection: pg_wire.PgConnection): Promise<void>;
    getInstance(syncRules: storage.PersistedSyncRulesContent, options?: GetIntanceOptions): storage.SyncRulesBucketStorage;
    getStorageMetrics(): Promise<storage.StorageMetrics>;
    getPowerSyncInstanceId(): Promise<string>;
    getSystemIdentifier(): Promise<storage.BucketStorageSystemIdentifier>;
    configureSyncRules(options: UpdateSyncRulesOptions): Promise<{
        updated: boolean;
        persisted_sync_rules?: storage.PersistedSyncRulesContent;
        lock?: storage.ReplicationLock;
    }>;
    updateSyncRules(options: storage.UpdateSyncRulesOptions): Promise<PostgresPersistedSyncRulesContent>;
    restartReplication(sync_rules_group_id: number): Promise<void>;
    getActiveSyncRules(options: storage.ParseSyncRulesOptions): Promise<storage.PersistedSyncRules | null>;
    getActiveSyncRulesContent(): Promise<storage.PersistedSyncRulesContent | null>;
    getNextSyncRules(options: storage.ParseSyncRulesOptions): Promise<storage.PersistedSyncRules | null>;
    getNextSyncRulesContent(): Promise<storage.PersistedSyncRulesContent | null>;
    getReplicatingSyncRules(): Promise<storage.PersistedSyncRulesContent[]>;
    getStoppedSyncRules(): Promise<storage.PersistedSyncRulesContent[]>;
    getActiveStorage(): Promise<SyncRulesBucketStorage | null>;
}
