import * as lib_postgres from '@powersync/lib-service-postgres';
import { CheckpointChanges, GetCheckpointChangesOptions, InternalOpId, storage, utils, WatchWriteCheckpointOptions } from '@powersync/service-core';
import * as sync_rules from '@powersync/service-sync-rules';
import { RequiredOperationBatchLimits } from '../types/types.js';
import * as framework from '@powersync/lib-services-framework';
import { PostgresWriteCheckpointAPI } from './checkpoints/PostgresWriteCheckpointAPI.js';
import { PostgresBucketStorageFactory } from './PostgresBucketStorageFactory.js';
export type PostgresSyncRulesStorageOptions = {
    factory: PostgresBucketStorageFactory;
    db: lib_postgres.DatabaseClient;
    sync_rules: storage.PersistedSyncRulesContent;
    write_checkpoint_mode?: storage.WriteCheckpointMode;
    batchLimits: RequiredOperationBatchLimits;
};
export declare class PostgresSyncRulesStorage extends framework.BaseObserver<storage.SyncRulesBucketStorageListener> implements storage.SyncRulesBucketStorage {
    protected options: PostgresSyncRulesStorageOptions;
    readonly group_id: number;
    readonly sync_rules: storage.PersistedSyncRulesContent;
    readonly slot_name: string;
    readonly factory: PostgresBucketStorageFactory;
    private sharedIterator;
    protected db: lib_postgres.DatabaseClient;
    protected writeCheckpointAPI: PostgresWriteCheckpointAPI;
    private parsedSyncRulesCache;
    private checksumCache;
    constructor(options: PostgresSyncRulesStorageOptions);
    get writeCheckpointMode(): storage.WriteCheckpointMode;
    getParsedSyncRules(options: storage.ParseSyncRulesOptions): sync_rules.SqlSyncRules;
    reportError(e: any): Promise<void>;
    compact(options?: storage.CompactOptions): Promise<void>;
    batchCreateCustomWriteCheckpoints(checkpoints: storage.BatchedCustomWriteCheckpointOptions[]): Promise<void>;
    lastWriteCheckpoint(filters: storage.SyncStorageLastWriteCheckpointFilters): Promise<bigint | null>;
    setWriteCheckpointMode(mode: storage.WriteCheckpointMode): void;
    createManagedWriteCheckpoint(checkpoint: storage.ManagedWriteCheckpointOptions): Promise<bigint>;
    getCheckpoint(): Promise<storage.ReplicationCheckpoint>;
    resolveTable(options: storage.ResolveTableOptions): Promise<storage.ResolveTableResult>;
    startBatch(options: storage.StartBatchOptions, callback: (batch: storage.BucketStorageBatch) => Promise<void>): Promise<storage.FlushedResult | null>;
    getParameterSets(checkpoint: utils.InternalOpId, lookups: sync_rules.ParameterLookup[]): Promise<sync_rules.SqliteJsonRow[]>;
    getBucketDataBatch(checkpoint: InternalOpId, dataBuckets: Map<string, InternalOpId>, options?: storage.BucketDataBatchOptions): AsyncIterable<storage.SyncBucketDataBatch>;
    getChecksums(checkpoint: utils.InternalOpId, buckets: string[]): Promise<utils.ChecksumMap>;
    terminate(options?: storage.TerminateOptions): Promise<void>;
    getStatus(): Promise<storage.SyncRuleStatus>;
    clear(): Promise<void>;
    autoActivate(): Promise<void>;
    private getChecksumsInternal;
    getActiveCheckpoint(): Promise<storage.ReplicationCheckpoint>;
    watchCheckpointChanges(options: WatchWriteCheckpointOptions): AsyncIterable<storage.StorageCheckpointUpdate>;
    protected watchActiveCheckpoint(signal: AbortSignal): AsyncIterable<storage.ReplicationCheckpoint>;
    getCheckpointChanges(options: GetCheckpointChangesOptions): Promise<CheckpointChanges>;
    private makeActiveCheckpoint;
}
